@@ -232,16 +232,20 @@ class UserRequest:
     requires_verification: bool = True
     password: str = None
     region: str = CountryCode.INDIA
+    id: str = None
 
     def to_dict(self):
         request = {
             "credential_type": self.credential_type.value,
             "identity": self.identity,
             "requires_verification": self.requires_verification,
-            "region": self.region,
+            "region": str(self.region),
         }
 
         if self.password:
             request["password"] = self.password
 
+        if self.id:
+            request["id"] = self.id
+
         return request
